from setuptools import find_packages, setup

setup(
    name="mb_cool_library",
    version="0.1.0",
    author="MB",
    author_email="mb@dev.pl",
    packages=find_packages(),
    include_package_data=True,
    description="Test test test"
)